repoze.profile
==============

.. image:: https://travis-ci.org/repoze/repoze.profile.png?branch=master
        :target: https://travis-ci.org/repoze/repoze.profile

.. image:: https://readthedocs.org/projects/repozeprofile/badge/?version=latest
        :target: http://repozeprofile.readthedocs.org/en/latest/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/repoze.profile.svg
   :target: https://pypi.python.org/pypi/repoze.profile

.. image:: https://img.shields.io/pypi/pyversions/repoze.profile.svg
   :target: https://pypi.python.org/pypi/repoze.profile

This package provides a WSGI middleware component which aggregates profiling
data across all requests to a WSGI application.  It provides a minimal web
GUI for viewing profiling data.

Installation
------------

Install using setuptools, e.g. (within a virtualenv)::

 $ easy_install repoze.profile

or via pip::

 $ pip install repoze.profile

Usage
-----

For details on using the various components, please see the
documentation in ``docs/index.rst``.  A rendered version of that documentation
is also available online:

 - http://repozeprofile.readthedocs.io/en/latest/


Reporting Bugs 
--------------

Please report bugs in this package to

  https://github.com/repoze/repoze.profile/issues


Obtaining Source Code
---------------------

Download development or tagged versions of the software by visiting:

  https://github.com/repoze/repoze.profile

